@@ -124,6 +124,7 @@ def url_info(url, faker = False):
         'video/f4v': 'flv',
         'video/mp4': 'mp4',
         'video/MP2T': 'ts',
+        'video/quicktime': 'mov',
         'video/webm': 'webm',
         'video/x-flv': 'flv',
         'video/x-ms-asf': 'asf',
@@ -234,7 +235,7 @@ def url_save(url, filepath, bar, refer = None, is_part = False, faker = False):
                 if bar:
                     bar.update_received(len(buffer))
     
-    assert received == os.path.getsize(temp_filepath), '%s == %s == %s' % (received, os.path.getsize(temp_filepath))
+    assert received == os.path.getsize(temp_filepath), '%s == %s == %s' % (received, os.path.getsize(temp_filepath), temp_filepath)
     
     if os.access(filepath, os.W_OK):
         os.remove(filepath) # on Windows rename could fail if destination filepath exists
@@ -443,8 +444,8 @@ def download_urls(urls, title, ext, total_size, output_dir = '.', refer = None,
             except:
                 from .processor.ffmpeg import has_ffmpeg_installed
                 if has_ffmpeg_installed():
-                    from .processor.ffmpeg import ffmpeg_concat_mp4_to_mpg
-                    ffmpeg_concat_mp4_to_mpg(parts, os.path.join(output_dir, title + '.mp4'))
+                    from .processor.ffmpeg import ffmpeg_concat_mp4_to_mp4
+                    ffmpeg_concat_mp4_to_mp4(parts, os.path.join(output_dir, title + '.mp4'))
                     for part in parts:
                         os.remove(part)
                 else:
@@ -536,16 +537,22 @@ def playlist_not_supported(name):
     return f
 
 def print_info(site_info, title, type, size):
+    if type:
+        type = type.lower()
     if type in ['3gp']:
         type = 'video/3gpp'
     elif type in ['asf', 'wmv']:
         type = 'video/x-ms-asf'
     elif type in ['flv', 'f4v']:
         type = 'video/x-flv'
+    elif type in ['mkv']:
+        type = 'video/x-matroska'
     elif type in ['mp3']:
         type = 'audio/mpeg'
     elif type in ['mp4']:
         type = 'video/mp4'
+    elif type in ['mov']:
+        type = 'video/quicktime'
     elif type in ['ts']:
         type = 'video/MP2T'
     elif type in ['webm']:
@@ -563,10 +570,10 @@ def print_info(site_info, title, type, size):
         type_info = "WebM video (%s)" % type
     #elif type in ['video/ogg']:
     #    type_info = "Ogg video (%s)" % type
-    #elif type in ['video/quicktime']:
-    #    type_info = "QuickTime video (%s)" % type
-    #elif type in ['video/x-matroska']:
-    #    type_info = "Matroska video (%s)" % type
+    elif type in ['video/quicktime']:
+        type_info = "QuickTime video (%s)" % type
+    elif type in ['video/x-matroska']:
+        type_info = "Matroska video (%s)" % type
     #elif type in ['video/x-ms-wmv']:
     #    type_info = "Windows Media video (%s)" % type
     elif type in ['video/x-ms-asf']:
